@@ -1,7 +1,8 @@
  .onLoad <- function(libname, pkgname) { # nocov start
    if (!("methods" %in% .packages())) attachNamespace("methods")
-   loadRcppModules()
- } 
+     modules <- paste0("stan_fit4", names(stanmodels), "_mod")
+     for (m in modules) loadModule(m, what = TRUE)
+   } 
 .onAttach <- function(...) {
   rstanarmLib <- dirname(system.file(package = "eggCounts"))
 #  pkgdesc <- utils::packageDescription("eggCounts", lib.loc = eggCountsLib)
